import glob
import platform

from setuptools import setup

if 'Linux' in platform.platform():
    extension = list(glob.glob('src/lasp/lasp_cpp.cpython*'))
    if len(extension) == 0:
        raise RuntimeError('Please first run CMake to build extension')
    elif len(extension) > 1:
        raise RuntimeError('Too many extension files found')

    pkgdata = extension

else:
    raise RuntimeError('Not yet Windows-proof')

classifiers = [
    "Topic :: Scientific/Engineering",
    "Programming Language :: Python :: 3.8",
    "Operating System :: POSIX :: Linux",
    "Operating System :: Microsoft :: Windows",
]

keywords = ["DSP", "DAQ", "Signal processing"]

with open('README.md', 'r') as f:
    readme = f.read()


setup(
    name="lasp",
    version="1.0",
    description="LASP: Library for Acoustic Signal Processing",

    author='J.A. de Jong (ASCEE / Redu-Sone)',
    author_email='info@ascee.nl',

    url='https://www.ascee.nl/lasp',
    classifiers=classifiers,
    keywords=keywords,
    license="MIT",
    readme=readme,
    dependencies=["numpy", "scipy", "appdirs", "h5py", "appdirs",
                "dataclasses_json"],
    packages=['lasp', 'lasp.filter', 'lasp.tools'],
    data_files = pkgdata,
    include_package_data=True,
    package_dir={'': 'src'},
    python_requires='>=3.8',
)
